MEGARA Analysis tools
=====================

Primary authors:

* Armando Gil de Paz <agil@fis.ucm.es>
* Sergio Pascual <sergiopr@fis.ucm.es>
* Mario Chamorro Cazorla <mariocha@ucm.es>
* África Castillo Morales <acasmor@fis.ucm.es>
